@@ -1,10 +1,10 @@
-use v5.10;
+use 5.008001;
 use strict;
 use warnings;
 
 package Path::Tiny;
 # ABSTRACT: File path utility
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 # Dependencies
 use autodie 2.00;
@@ -13,7 +13,7 @@ use Exporter   (qw/import/);
 use Fcntl      (qw/:flock SEEK_END/);
 use File::Copy ();
 use File::stat ();
-use File::Path 2.07 ();
+{ no warnings; use File::Path 2.07 (); } # avoid "2.07_02 isn't numeric"
 use File::Spec 3.40 ();
 use File::Temp 0.18 ();
 
@@ -50,8 +50,8 @@ sub _check_UU {
 
 
 sub path {
-    my $path = shift // ".";
-    $path = "." unless length $path;
+    my $path = shift;
+    $path = "." unless defined $path && length $path;
     # join stringifies any objects, too, which is handy :-)
     $path = join( "/", ( $path eq '/' ? "" : $path ), @_ ) if @_;
     my $cpath = $path = File::Spec->canonpath($path); # ugh, but probably worth it
@@ -67,20 +67,42 @@ sub new { shift; path(@_) }
 sub rootdir { path( File::Spec->rootdir ) }
 
 
-sub tempfile { shift; unshift @_, 'new'; goto &_temp }
-
-
-sub tempdir { shift; unshift @_, 'newdir'; goto &_temp }
-
-sub _temp {
-    my ( $method, @args ) = @_;
-    my $temp = File::Temp->$method( TMPDIR => 1, @args );
-    close $temp if $method eq 'new'; # so we can unlink it safely if needed
+sub tempfile {
+    my $class = shift;
+    my ( $maybe_template, $args ) = _parse_file_temp_args(@_);
+    # File::Temp->new demands TEMPLATE
+    $args->{TEMPLATE} = $maybe_template->[0] if @$maybe_template;
+    my $temp = File::Temp->new( TMPDIR => 1, %$args );
+    close $temp;
     my $self = path($temp);
-    $self->[TEMP] = $temp;           # keep object alive while we are
+    $self->[TEMP] = $temp; # keep object alive while we are
     return $self;
 }
 
+
+sub tempdir {
+    my $class = shift;
+    my ( $maybe_template, $args ) = _parse_file_temp_args(@_);
+    # File::Temp->newdir demands leading template
+    my $temp = File::Temp->newdir( @$maybe_template, TMPDIR => 1, %$args );
+    my $self = path($temp);
+    $self->[TEMP] = $temp; # keep object alive while we are
+    return $self;
+}
+
+# normalize the various ways File::Temp does templates
+sub _parse_file_temp_args {
+    my $leading_template = ( scalar(@_) % 2 == 1 ? shift(@_) : '' );
+    my %args = @_;
+    %args = map { uc($_), $args{$_} } keys %args;
+    my @template = (
+          exists $args{TEMPLATE} ? delete $args{TEMPLATE}
+        : $leading_template      ? $leading_template
+        :                          ()
+    );
+    return ( \@template, \%args );
+}
+
 #--------------------------------------------------------------------------#
 # Private methods
 #--------------------------------------------------------------------------#
@@ -98,7 +120,7 @@ sub _splitpath {
 sub absolute {
     my ( $self, $base ) = @_;
     return $self if $self->is_absolute;
-    return path( join "/", $base // Cwd::getcwd, $_[0]->[PATH] );
+    return path( join "/", ( defined($base) ? $base : Cwd::getcwd ), $_[0]->[PATH] );
 }
 
 
@@ -117,7 +139,7 @@ sub append_raw { splice @_, 1, 0, { binmode => ":unix" }; goto &append }
 
 
 sub append_utf8 {
-    if ( $HAS_UU //= _check_UU() ) {
+    if ( defined($HAS_UU) ? $HAS_UU : $HAS_UU = _check_UU() ) {
         my $self = shift;
         append( $self, { binmode => ":unix" }, map { Unicode::UTF8::encode_utf8($_) } @_ );
     }
@@ -173,8 +195,8 @@ sub exists { -e $_[0]->[PATH] }
 
 sub filehandle {
     my ( $self, $mode, $binmode ) = @_;
-    $mode    //= "<";
-    $binmode //= "";
+    $mode    = "<" unless defined $mode;
+    $binmode = ""  unless defined $binmode;
     open my $fh, "$mode$binmode", $self->[PATH];
     return $fh;
 }
@@ -218,7 +240,7 @@ sub lines {
     if ( $args->{count} ) {
         return map { chomp if $chomp; $_ } map { scalar <$fh> } 1 .. $args->{count};
     }
-    elsif ( $chomp ) {
+    elsif ($chomp) {
         return map { chomp; $_ } <$fh>;
     }
     else {
@@ -241,7 +263,10 @@ sub lines_raw {
 
 sub lines_utf8 {
     $_[1] = {} unless ref $_[1] eq 'HASH';
-    if ( ( $HAS_UU //= _check_UU() ) && $_[1]->{chomp} && !$_[1]->{count} ) {
+    if (   ( defined($HAS_UU) ? $HAS_UU : $HAS_UU = _check_UU() )
+        && $_[1]->{chomp}
+        && !$_[1]->{count} )
+    {
         return split /\n/, slurp_utf8( $_[0] ); ## no critic
     }
     else {
@@ -329,7 +354,9 @@ sub slurp {
     $args = {} unless ref $args eq 'HASH';
     my $fh = $self->filehandle( "<", $args->{binmode} );
     flock( $fh, LOCK_SH );
-    if ( ( $args->{binmode} // "" ) eq ":unix" and my $size = -s $fh ) {
+    if ( ( defined( $args->{binmode} ) ? $args->{binmode} : "" ) eq ":unix"
+        and my $size = -s $fh )
+    {
         my $buf;
         read $fh, $buf, $size; # File::Slurp in a nutshell
         return $buf;
@@ -345,7 +372,7 @@ sub slurp_raw { $_[1] = { binmode => ":unix" }; goto &slurp }
 
 
 sub slurp_utf8 {
-    if ( $HAS_UU //= _check_UU() ) {
+    if ( defined($HAS_UU) ? $HAS_UU : $HAS_UU = _check_UU() ) {
         return Unicode::UTF8::decode_utf8( slurp( $_[0], { binmode => ":unix" } ) );
     }
     else {
@@ -375,7 +402,7 @@ sub spew_raw { splice @_, 1, 0, { binmode => ":unix" }; goto &spew }
 
 
 sub spew_utf8 {
-    if ( $HAS_UU //= _check_UU() ) {
+    if ( defined($HAS_UU) ? $HAS_UU : $HAS_UU = _check_UU() ) {
         my $self = shift;
         spew( $self, { binmode => ":unix" }, map { Unicode::UTF8::encode_utf8($_) } @_ );
     }
@@ -434,7 +461,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.008
+version 0.010
 
 =head1 SYNOPSIS
 
@@ -529,12 +556,19 @@ picky for C<path("/")>.
     $temp = Path::Tiny->tempfile( @options );
 
 This passes the options to C<< File::Temp->new >> and returns a C<Path::Tiny>
-object with the file name.  If you want a template, you must use a C<TEMPLATE>
-named argument.  The C<TMPDIR> option is enabled by default.
+object with the file name.  The C<TMPDIR> option is enabled by default.
 
 The resulting C<File::Temp> object is cached. When the C<Path::Tiny> object is
 destroyed, the C<File::Temp> object will be as well.
 
+C<File::Temp> annoyingly requires you to specify a custom template in slightly
+different ways depending on which function or method you call, but
+C<Path::Tiny> lets you ignore that and can take either a leading template or a
+C<TEMPLATE> option and does the right thing.
+
+    $temp = Path::Tiny->tempfile( "customXXXXXXXX" );             # ok
+    $temp = Path::Tiny->tempfile( TEMPLATE => "customXXXXXXXX" ); # ok
+
 =head2 tempdir
 
     $temp = Path::Tiny->tempdir( @options );
